summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authormainframe98 <k.s.werf@hotmail.com>2021-12-28 15:06:55 +0100
committermainframe98 <k.s.werf@hotmail.com>2021-12-28 15:06:55 +0100
commit67abc01031fb4a450ab0b43fdeac2d0c9992b456 (patch)
tree499b23ef6539a63848dfce0a98f767e4d0bf72cd
parent3d1dd5246beb7240fb2ec0bffe3207f90a7348c8 (diff)
Export bindToggleOnEnter
Follow-up to 98b18288ebdd11e7a321b81c4facfc3b5da1e98c. Bug: T294164 Change-Id: I46bb9930edd908914aea2cfe071816fcdf216523
-rw-r--r--resources/src/mediawiki.page.ready/checkboxHack.js3
1 files changed, 2 insertions, 1 deletions
diff --git a/resources/src/mediawiki.page.ready/checkboxHack.js b/resources/src/mediawiki.page.ready/checkboxHack.js
index 80862c6307c5..c35e6b2ab984 100644
--- a/resources/src/mediawiki.page.ready/checkboxHack.js
+++ b/resources/src/mediawiki.page.ready/checkboxHack.js
@@ -308,7 +308,7 @@ function bindToggleOnSpaceEnter( checkbox, button ) {
}
/**
* Manually change the checkbox state when the button is focused and SPACE is pressed.
*
* @param {HTMLInputElement} checkbox
* @return {function(): void} Cleanup function that removes the added event listeners.
@@ -411,6 +411,7 @@ module.exports = {
bindUpdateAriaExpandedOnInput: bindUpdateAriaExpandedOnInput,
bindToggleOnClick: bindToggleOnClick,
bindToggleOnSpaceEnter: bindToggleOnSpaceEnter,
+ bindToggleOnEnter: bindToggleOnEnter,
bindDismissOnClickOutside: bindDismissOnClickOutside,
bindDismissOnFocusLoss: bindDismissOnFocusLoss,
bind: bind
@@ -308,7 +308,7 @@ function bindToggleOnSpaceEnter( checkbox, button ) {
}
/**
- * Manually change the checkbox state when the button is focused and SPACE is pressed.
+ * Manually change the checkbox state when the button is focused and Enter is pressed.
*
* @param {HTMLInputElement} checkbox